@@ -26,6 +26,8 @@ describe 'basic aodh' do
         provider             => 'rabbitmqctl',
         require              => Class['rabbitmq'],
       }
+      # https://bugs.launchpad.net/aodh/+bug/1557154
+      Rabbitmq_user_permissions['aodh@/'] -> Service<| tag == 'aodh-service' |>
 
       class { '::aodh':
         rabbit_userid       => 'aodh',
@@ -43,7 +45,7 @@ describe 'basic aodh' do
       class { '::aodh::api':
         enabled               => true,
         keystone_password     => 'a_big_secret',
-        keystone_identity_uri => 'http://127.0.0.1:35357/',
+        keystone_auth_uri     => 'http://127.0.0.1:5000',
         service_name          => 'httpd',
       }
       include ::apache
